#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'find-dialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "/pub/devel/octave/octave-6.4.0-1.x86_64/src/octave-6.4.0/libgui/src/m-editor/find-dialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'find-dialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__find_dialog_t {
    QByteArrayData data[14];
    char stringdata0[205];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__find_dialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__find_dialog_t qt_meta_stringdata_octave__find_dialog = {
    {
QT_MOC_LITERAL(0, 0, 19), // "octave::find_dialog"
QT_MOC_LITERAL(1, 20, 9), // "find_next"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 9), // "find_prev"
QT_MOC_LITERAL(4, 41, 16), // "update_edit_area"
QT_MOC_LITERAL(5, 58, 18), // "octave_qscintilla*"
QT_MOC_LITERAL(6, 77, 25), // "handle_sel_search_changed"
QT_MOC_LITERAL(7, 103, 24), // "handle_selection_changed"
QT_MOC_LITERAL(8, 128, 12), // "has_selected"
QT_MOC_LITERAL(9, 141, 30), // "handle_backward_search_changed"
QT_MOC_LITERAL(10, 172, 4), // "find"
QT_MOC_LITERAL(11, 177, 7), // "forward"
QT_MOC_LITERAL(12, 185, 7), // "replace"
QT_MOC_LITERAL(13, 193, 11) // "replace_all"

    },
    "octave::find_dialog\0find_next\0\0find_prev\0"
    "update_edit_area\0octave_qscintilla*\0"
    "handle_sel_search_changed\0"
    "handle_selection_changed\0has_selected\0"
    "handle_backward_search_changed\0find\0"
    "forward\0replace\0replace_all"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__find_dialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x0a /* Public */,
       3,    0,   65,    2, 0x0a /* Public */,
       4,    1,   66,    2, 0x0a /* Public */,
       6,    1,   69,    2, 0x08 /* Private */,
       7,    1,   72,    2, 0x08 /* Private */,
       9,    1,   75,    2, 0x08 /* Private */,
      10,    1,   78,    2, 0x08 /* Private */,
      10,    0,   81,    2, 0x28 /* Private | MethodCloned */,
      12,    0,   82,    2, 0x08 /* Private */,
      13,    0,   83,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void octave::find_dialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        find_dialog *_t = static_cast<find_dialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->find_next(); break;
        case 1: _t->find_prev(); break;
        case 2: _t->update_edit_area((*reinterpret_cast< octave_qscintilla*(*)>(_a[1]))); break;
        case 3: _t->handle_sel_search_changed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->handle_selection_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->handle_backward_search_changed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->find((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->find(); break;
        case 8: _t->replace(); break;
        case 9: _t->replace_all(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< octave_qscintilla* >(); break;
            }
            break;
        }
    }
}

const QMetaObject octave::find_dialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_octave__find_dialog.data,
      qt_meta_data_octave__find_dialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::find_dialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::find_dialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__find_dialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int octave::find_dialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
